==> zio-aws-rekognition_2.12-5.17.157.1-sources.jar: zio/aws/rekognition/model/Eyeglasses.scala <==
package zio.aws.rekognition.model
import zio.aws.rekognition.model.primitives.Percent
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class Eyeglasses(
    value: Option[Boolean] = None,
    confidence: Option[Percent] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rekognition.model.Eyeglasses = {
    import Eyeglasses.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rekognition.model.Eyeglasses
      .builder()
      .optionallyWith(value.map(value => value: java.lang.Boolean))(_.value)
      .optionallyWith(
        confidence.map(value => Percent.unwrap(value): java.lang.Float)
      )(_.confidence)
      .build()
  }
  def asReadOnly: zio.aws.rekognition.model.Eyeglasses.ReadOnly =
    zio.aws.rekognition.model.Eyeglasses.wrap(buildAwsValue())
}
object Eyeglasses {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rekognition.model.Eyeglasses
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rekognition.model.Eyeglasses =
      zio.aws.rekognition.model
        .Eyeglasses(value.map(value => value), confidence.map(value => value))
    def value: Option[Boolean]
    def confidence: Option[Percent]
    def getValue: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("value", value)
    def getConfidence: ZIO[Any, AwsError, Percent] =
      AwsError.unwrapOptionField("confidence", confidence)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rekognition.model.Eyeglasses
  ) extends zio.aws.rekognition.model.Eyeglasses.ReadOnly {
    override val value: Option[Boolean] =
      scala.Option(impl.value()).map(value => value: Boolean)
    override val confidence: Option[Percent] = scala
      .Option(impl.confidence())
      .map(value => zio.aws.rekognition.model.primitives.Percent(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rekognition.model.Eyeglasses
  ): zio.aws.rekognition.model.Eyeglasses.ReadOnly = new Wrapper(impl)
}

==> zio-aws-rekognition_2.12-5.20.7.1-sources.jar: zio/aws/rekognition/model/Eyeglasses.scala <==
package zio.aws.rekognition.model
import zio.aws.rekognition.model.primitives.Percent
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class Eyeglasses(
    value: Optional[Boolean] = Optional.Absent,
    confidence: Optional[Percent] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rekognition.model.Eyeglasses = {
    import Eyeglasses.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rekognition.model.Eyeglasses
      .builder()
      .optionallyWith(value.map(value => value: java.lang.Boolean))(_.value)
      .optionallyWith(
        confidence.map(value => Percent.unwrap(value): java.lang.Float)
      )(_.confidence)
      .build()
  }
  def asReadOnly: zio.aws.rekognition.model.Eyeglasses.ReadOnly =
    zio.aws.rekognition.model.Eyeglasses.wrap(buildAwsValue())
}
object Eyeglasses {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rekognition.model.Eyeglasses
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rekognition.model.Eyeglasses =
      zio.aws.rekognition.model
        .Eyeglasses(value.map(value => value), confidence.map(value => value))
    def value: Optional[Boolean]
    def confidence: Optional[Percent]
    def getValue: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("value", value)
    def getConfidence: ZIO[Any, AwsError, Percent] =
      AwsError.unwrapOptionField("confidence", confidence)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rekognition.model.Eyeglasses
  ) extends zio.aws.rekognition.model.Eyeglasses.ReadOnly {
    override val value: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.value())
      .map(value => value: Boolean)
    override val confidence: Optional[Percent] = zio.aws.core.internal
      .optionalFromNullable(impl.confidence())
      .map(value => zio.aws.rekognition.model.primitives.Percent(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rekognition.model.Eyeglasses
  ): zio.aws.rekognition.model.Eyeglasses.ReadOnly = new Wrapper(impl)
}
